Func

Struct Func 

pub struct Func(/* private fields */);
A Wasm function.

A Func is either a Wasm function or a host function.

Implementations

Source

impl Func

pub fn wrap<Ts, U>(store: &mut Store, f: impl IntoFunc<Ts, U>) -> Self

Creates a new host function that wraps the given closure.

pub fn type_(self, store: &Store) -> &FuncType

Returns the FuncType of this Func.

pub fn call( self, store: &mut Store, args: &[Val], results: &mut [Val], ) -> Result<(), Error>

Calls this Func with the given arguments.

The results are written to the results slice.

Errors
  • If the argument count does not match the expected parameter count.
  • If the actual result count does not match the expected result count.
  • If the argument types do not match the expected parameter types.